Installation
============

There are several ways to download and install Django-flash:

**Via PyPI**

  Execute the following command line to download and install the latest
  stable version from CheeseShop_::

      $ easy_install -U django-flash

  Follow `these <http://pypi.python.org/pypi/setuptools>`_ instructions to
  install EasyInstall_ if you don't have it already.


**Via GitHub**

  If you are a Git_ user and want to take a closer look at the project's
  source code, you would rather clone our
  `public repository <http://github.com/danielfm/django-flash/tree/master>`_
  instead::

      $ git clone git://github.com/danielfm/django-flash.git
      $ cd django-flash
      $ python setup.py install


**Zip file/tarball**

  Django-flash is also available for download as
  `compressed archives <http://github.com/danielfm/django-flash/downloads>`_
  (either ``zip`` and ``tgz``). After unzip/untar the archive, execute the
  following command to install Django-flash::
  
      $ python setup.py install


.. _EasyInstall: http://peak.telecommunity.com/DevCenter/EasyInstall
.. _CheeseShop: http://pypi.python.org/pypi
.. _Git: http://git-scm.com/

